darkhistory.physics.H0 — DarkHistory documentation

- Repository
- DarkHistory documentation
- DarkHistory
- darkhistory
- darkhistory.physics

- index
- modules
- next
- previous

# darkhistory.physics.H0

`darkhistory.physics.` `H0` = 2.1748869673182562e-18

  Hubble parameter today in s-1.

#### Previous topic

darkhistory.physics.h

#### Next topic

darkhistory.physics.omega_m

### This Page

Show Source

- © Copyright 2019, Hongwan Liu, Gregory Ridgway and Tracy Slatyer.
- Created using Sphinx 1.8.5.